{% load django_action_logger %}
{% regroup object_list by action_time|date as object_by_date %}
{% for logentry_date in object_by_date %}
    <h1 class="text-center logentry-date">{{ logentry_date.grouper }}</h1>
    <ul class="logentry-list">
        {% for object in logentry_date.list %}
            <li class="logentry-list-item">{% include object|template_names %}</li>
        {% endfor %}
    </ul>
{% endfor %}
<div class="pagination justify-content-center">
    <span class="step-links">
        {% if page_obj.has_previous %}
            <a href="?page=1">&laquo; first</a>
            <a href="?page={{ page_obj.previous_page_number }}">previous</a>
        {% endif %}
        <span class="current">Page {{ page_obj.number }} of {{ page_obj.paginator.num_pages }}.</span>
        {% if page_obj.has_next %}
            <a href="?page={{ page_obj.next_page_number }}">next</a>
            <a href="?page={{ page_obj.paginator.num_pages }}">last &raquo;</a>
        {% endif %}
    </span>
</div>
